// message listener
chrome.runtime.onMessage.addListener(
    function (request, sender, sendResponse) {
        if (enableLog) {
            console.log('request:', request);
        }
        // console.log(sender.tab ?
        //     "from a content script:" + sender.tab.url :
        //     "from the extension");
        if (request["to_do"] === "update_storage_variables") {
            updateStorageVariables();
            sendResponse("done");
        }
    },
);

var enableLog = true;

var setting;

function updateStorageVariables() {
    chrome.storage.local.get('user_agent_setting_storage', function (item) {
        if (item) {
            if (item['user_agent_setting_storage']) {
                setting = JSON.parse(item['user_agent_setting_storage']);
            }
        }
    });
}

function applyListener() {
    chrome.webRequest.onBeforeSendHeaders.addListener(
        function (info) {
            if (setting) {

                if (enableLog) {
                    console.log("setting:", setting);
                }

                var finalUserAgentValue = '';
                if (setting.enable === false) {
                    console.log('not enabled, returning');
                    // not enabled, return
                    return {requestHeaders: info.requestHeaders};
                }
                if (setting.useCustomUserAgentString === true) {
                    // user custom user agent string
                    finalUserAgentValue = setting.customUserAgentString;
                }
                if (setting.usePreDefinedUserAgentString) {
                    finalUserAgentValue = setting.userAgentValue;
                }

                var userAgentSet = null;
                var cacheControlSet = null;

                for (var index = 0, len = info.requestHeaders.length; index < len; index++) {
                    if (info.requestHeaders[index].name.toLowerCase() === 'User-Agent') {
                        info.requestHeaders[index].value = finalUserAgentValue;
                        userAgentSet = true;
                    }
                    if (info.requestHeaders[index].name.toLowerCase() === 'Cache-Control') {
                        info.requestHeaders[index].value = 'max-age=0';
                        cacheControlSet = true;
                    }
                }
                if (!userAgentSet) {
                    info.requestHeaders.push({
                        'name': 'User-Agent',
                        'value': finalUserAgentValue,
                    });
                }
                if (!cacheControlSet) {
                    info.requestHeaders.push({
                        'name': 'Cache-Control',
                        'value': 'max-age=0',
                    });
                }
            }
            return {requestHeaders: info.requestHeaders};
        },
        {
            urls: ["http://*/*", "https://*/*"],
            types: ["main_frame", "sub_frame", "stylesheet", "script", "image", "object", "xmlhttprequest", "other"],
        },
        ['blocking', 'requestHeaders', 'extraHeaders'],
    );
}

updateStorageVariables();
applyListener();